# friendica

#### Table of Contents

1. [Description](#description)
1. [Setup - The basics of getting started with friendica](#setup)
    * [What friendica affects](#what-friendica-affects)
    * [Setup requirements](#setup-requirements)
    * [Beginning with friendica](#beginning-with-friendica)
1. [Usage - Configuration options and additional functionality](#usage)
1. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
1. [Limitations - OS compatibility, etc.](#limitations)
1. [Development - Guide for contributing to the module](#development)

## Description

Puppet class to install and configure a Friendica instance
Friendica is a federated social platform. http://friendica.com

### What friendica affects

This module installs and configures a copy of the Friendica php
code in /var/www.

By default it will also setup nginx, php-fpm, mysql and nscd to suit
friendicas needs.

### Beginning with friendica

Add it to you existing puppet setup and see this manual for optional
settings. Or download the easy installer from
https://devtools.maljaars-it.nl/opensource/friendica-setup to use this
software without a full fledged puppet environment.

## Usage

    class { 'friendica':
      $service_name => "mycoolnodename.org",
      $admin_email => "sittingduck@aol.com",
    }


## Reference

* `tls_key`

Allow you to inject a TLS key that comes from eg encrypted hiera
(eyaml)

* `service_name`

The DNS name the friendica instance should serve. Defaults to the
full qualified domain name of the server / node.

* `admin_mail`

Working email address of the server admin. Use this email address to
register the first account on your Friendica instance after setup.
Defauls to info@`service_name`

* `mysql_web_user`

The mysql user name that the friendica application uses to connect
to mysql. Defaults to friendica-www

* `mysql_web_password`

THe mysql password that the friendica application uses to connect
to mysql. Has a default which may be ok if MySQL security is otherwise
sane. But feeding it an eyaml encrypted alternative is better.

* `mysql_db_name`

MySQL database name to use, defaults to 'friendica'

* `branch`

The Friendica code is deployed using a git clone command. This
options allows you to specify an alternative git branch to check out
Defaults to develop.

Please note the the checkout is only performed during setup. Updates
currently must be done manually using a git pull.

* `download_url`

Option to specify an other GIT repository, defaults to the friendica
public repo on Github.

* `manage_mysql`

Wether to setup MySQL using the included puppet code. Defaults to true.

* `manage_nginx`

Wether to setup nginx using the included puppet code. Defaults to true.

* `manage_php`

Wether to setup php/php-fpm using the included puppet code. Defaults to true.

* `manage_nscd`

Wether to setup nscd (name serving caching daemon) using the included puppet code. Defaults to true.

* `manage_firewall`

Wether to setup a firewall rule using the included puppet code. Defaults to true.


## Limitations

For now only tested in Ubuntu 16.04 and Debian 8 on amd64.

## Development

Development for this module is managed in a Gitlab instance at
https://devtools.maljaars-it.nl/opensource/puppet-friendica. Please feel
free to raise issues or send PR there.
